summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/or/router.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/or/router.c b/src/or/router.c
index 6199e9e3cc..451d95d03c 100644
--- a/src/or/router.c
+++ b/src/or/router.c
@@ -654,17 +654,18 @@ init_keys(void)
}
added = dirserv_add_descriptor(ri, &m, "self");
if (!WRA_WAS_ADDED(added)) {
- if (WRA_WAS_REJECTED(added)) {
+ if (!WRA_WAS_OUTDATED(added)) {
log_err(LD_GENERAL, "Unable to add own descriptor to directory: %s",
m?m:"<unknown error>");
return -1;
} else {
/* If the descriptor wasn't rejected, that's ok. This can happen
* when some config options are toggled that affect workers, but
* we don't really need new keys yet so the descriptor doesn't
* change and the old one is still fresh. */
- log_info(LD_GENERAL, "Couldn't add own descriptor to directory: %s",
- m?m:"unknown error>");
+ log_info(LD_GENERAL, "Couldn't add own descriptor to directory "
+ "after key init: %s. This is usually not a problem.",
+ m?m:"<unknown error>");
}
}
}
@@ -654,17 +654,18 @@ init_keys(void)
return -1;
} else {
- /* If the descriptor wasn't rejected, that's ok. This can happen
+ /* If the descriptor was outdated, that's ok. This can happen
* when some config options are toggled that affect workers, but
* we don't really need new keys yet so the descriptor doesn't